# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/st/iksc/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/st/iksc/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "St\\Iksc\\": "packages/st/iksc/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        St\Iksc\Providers\IkscServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Iksc'  => St\Iksc\Facades\Iksc::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=St\\IkscTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="St\Iksc\Providers\IkscServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="St\Iksc\Providers\IkscServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="St\Iksc\Providers\IkscServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/iksc/{modulename}

**User**

    http://path-to-route-folder/user/iksc/{modulename}

**Public**

    http://path-to-route-folder/ikscs


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/iksc/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/iksc/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/iksc/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/iksc/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/iksc/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/iksc/{modulename}/{slug}
    METHOD: GET